@@ -825,15 +825,23 @@ public class TorProcess extends ClientProcess {
         if (version == 9999) {
             BufferedReader br;
             String strVer = "";
+            Process proc;
             try {
-                Process proc = Runtime.getRuntime().exec(strClientLocation + " --version");
-                if (proc.waitFor() == 0) {
-                    br = new BufferedReader(new InputStreamReader(proc.getInputStream()), 256);
-                    strVer = br.readLine();
-                    br.close();
+                proc = Runtime.getRuntime().exec(strClientLocation + " --version");
+                br = new BufferedReader(new InputStreamReader(proc.getInputStream()), 256);
+                String line;
+                while (true) {
+                    line = br.readLine();
+                    if (line == null) {
+                        break;
+                    }
+                    strVer = line;
                 }
+                br.close();
+                proc.destroyForcibly();
+                proc.waitFor();
             } catch (IOException | InterruptedException ex) {
-                Logger.getGlobal().logp(Level.SEVERE, this.getClass().getName(), "getVersion() Port=" + intListenPort, "", ex);
+                Logger.getLogger(TorProcess.class.getName()).log(Level.SEVERE, null, ex);
             }
             int idx = strVer.indexOf("ion");
             if (idx > -1) {
