@@ -295,12 +295,21 @@ public class OSFunction {
      */
     public static boolean isMultipleInstance(String appname) {
         if (alProcesses == null) {
-            alProcesses = getActiveProcesses();
+            alProcesses = getLiveProcesses();
         }
         ArrayList<String> processes = OSFunction.filterProcesses(appname);
         return OSFunction.filterProcesses(processes, "java").size() > 1;
     }
 
+    /**
+     * Cached list of processes
+     *
+     * @return list
+     */
+    public static ArrayList<String> getCachedProcesses() {
+        return alProcesses;
+    }
+
     /**
      * Find processes matching the contents of filter
      *
@@ -697,7 +706,7 @@ public class OSFunction {
      *
      * @return Arraylist of system process
      */
-    public static ArrayList<String> getActiveProcesses() {
+    public static ArrayList<String> getLiveProcesses() {
         if (isWindows()) {
             return getActiveProcessesWindows();
         } else {
@@ -755,7 +764,7 @@ public class OSFunction {
             return getOSName();
         }
         if (alProcesses == null) {
-            alProcesses = getActiveProcesses();
+            alProcesses = getLiveProcesses();
         }
         for (String s : alProcesses) {
             if (s.contains("kwin")) {
@@ -793,7 +802,7 @@ public class OSFunction {
         }
         String result = "unknown";
         if (alProcesses == null) {
-            alProcesses = getActiveProcesses();
+            alProcesses = getLiveProcesses();
         }
         for (String s : alProcesses) {
             if (s.contains("cinnamon-session")) {
